@@ -14,16 +14,18 @@
 import contextlib
 import re
 import tempfile
+from cStringIO import StringIO
 
 from . import errors
 from . import ipc
+from . import utils
 
 _language_pattern = re.compile('^[a-z]{3}(-[a-z]+)?$')
 _language_info_pattern = re.compile(r"^Supported languages: (.*)[.]$")
 
 _cuneiform_to_iso = dict(
     ger='deu',
-    ruseng='rus-eng', # mixed Russian-English
+    ruseng='rus-eng',  # mixed Russian-English
 )
 
 _iso_to_cuneiform = dict((y, x) for x, y in _cuneiform_to_iso.iteritems())
@@ -39,7 +41,7 @@ def get_languages():
         cuneiform = ipc.Subprocess(['cuneiform', '-l'],
             stdout=ipc.PIPE,
             stderr=ipc.PIPE,
-            env={}, # locale=POSIX
+            env={},  # locale=POSIX
         )
     except OSError:
         raise errors.UnknownLanguageList
@@ -69,9 +71,14 @@ def recognize(pbm_file, language):
     worker = ipc.Subprocess(
         ['cuneiform', '-l', iso_to_cuneiform(language), '-f', 'hocr', '-o', hocr_file.name, pbm_file.name],
         stdout=ipc.PIPE,
-        env={}, # locale=POSIX
+        env={},  # locale=POSIX
     )
     worker.wait()
-    return hocr_file
+    # Sometimes Cuneiform returns files with broken encoding or with control
+    # characters: https://bugs.launchpad.net/cuneiform-linux/+bug/585418
+    # Let's fix it.
+    contents = hocr_file.read()
+    contents = utils.sanitize_utf8(contents)
+    return contextlib.closing(StringIO(contents))
 
 # vim:ts=4 sw=4 et
